#!/usr/bin/env bash

#Lines beginning with # are comments.
#This file is a part of a Radiance Tutorial commissioned by the Lawrence Berkeley National Laboratory.
#Date:19 AUG 2017
#Created by Sarith Subramaniam(sarith@sarith.in)


#Commands for running a simulation with MULTIPLE WINDOW GROUPS WITH THE THREE-PHASE METHOD (variable heights).
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#These commands were tested on a dedicated Intel Xeon CPU E5-2680 (v2 @ 2.80GHz) processor.
#Processor runtime for executing all the commands (in seconds): 590

#NOTES:
#	Set the current working directory to "room" before running the commands below.
#	Commands are separated by empty line-breaks.
#	This simulation is for a point-in-time sky vector. Annual results can be generated by using a sky matrix generated through gendaymtx. That example is covered in 3PM.sh
#	While not implemented in this file due to platform-specific limitations, a more elegant way to approach such simulations will be through a for-loop.


#Create an octree
oconv -f materials.rad room.rad > octrees/room3ph.oct


#V matrices for Illuminance. Four matrices corresponding to four shading groups will be created.
rfluxmtx -v -I+ -ab 4 -ad 5000 -lw 0.0002 -n 16 -y 100  - varShading/GlazingVmtx1.rad -i octrees/room3ph.oct < points.txt > matrices/vmtx/v1.mtx

rfluxmtx -v -I+ -ab 4 -ad 5000 -lw 0.0002 -n 16 -y 100  - varShading/GlazingVmtx2.rad -i octrees/room3ph.oct < points.txt > matrices/vmtx/v2.mtx

rfluxmtx -v -I+ -ab 4 -ad 5000 -lw 0.0002 -n 16 -y 100  - varShading/GlazingVmtx3.rad -i octrees/room3ph.oct < points.txt > matrices/vmtx/v3.mtx

rfluxmtx -v -I+ -ab 4 -ad 5000 -lw 0.0002 -n 16 -y 100  - varShading/GlazingVmtx4.rad -i octrees/room3ph.oct < points.txt > matrices/vmtx/v4.mtx


#V matrices for Images. Four sets of matrices corresponding to four shading groups will be created.

vwrays -vf views/south.vf -x 300 -y 300 -pj 0.7 -c 9 -ff | rfluxmtx -v -ffc `vwrays -vf views/south.vf -x 300 -y 300 -d` -o matrices/vmtx/hdr/v1%03d.hdr -ab 4 -ad 1000 -lw 1e-4 -c 9 -n 16 - varShading/GlazingVmtx1.rad -i octrees/room3ph.oct

vwrays -vf views/south.vf -x 300 -y 300 -pj 0.7 -c 9 -ff | rfluxmtx -v -ffc `vwrays -vf views/south.vf -x 300 -y 300 -d` -o matrices/vmtx/hdr/v2%03d.hdr -ab 4 -ad 1000 -lw 1e-4 -c 9 -n 16 - varShading/GlazingVmtx2.rad -i octrees/room3ph.oct

vwrays -vf views/south.vf -x 300 -y 300 -pj 0.7 -c 9 -ff | rfluxmtx -v -ffc `vwrays -vf views/south.vf -x 300 -y 300 -d` -o matrices/vmtx/hdr/v3%03d.hdr -ab 4 -ad 1000 -lw 1e-4 -c 9 -n 16 - varShading/GlazingVmtx3.rad -i octrees/room3ph.oct

vwrays -vf views/south.vf -x 300 -y 300 -pj 0.7 -c 9 -ff | rfluxmtx -v -ffc `vwrays -vf views/south.vf -x 300 -y 300 -d` -o matrices/vmtx/hdr/v4%03d.hdr -ab 4 -ad 1000 -lw 1e-4 -c 9 -n 16 - varShading/GlazingVmtx4.rad -i octrees/room3ph.oct


#D Matrices corresponding to four shading groups.
rfluxmtx -v -ff  -ab 4 -ad 1000 -lw 0.001 -c 1000 -n 16 varShading/GlazingVmtx1.rad skyDomes/skyglow.rad -i octrees/room3ph.oct > matrices/dmtx/daylight1.dmx

rfluxmtx -v -ff  -ab 4 -ad 1000 -lw 0.001 -c 1000 -n 16 varShading/GlazingVmtx2.rad skyDomes/skyglow.rad -i octrees/room3ph.oct > matrices/dmtx/daylight2.dmx

rfluxmtx -v -ff  -ab 4 -ad 1000 -lw 0.001 -c 1000 -n 16 varShading/GlazingVmtx3.rad skyDomes/skyglow.rad -i octrees/room3ph.oct > matrices/dmtx/daylight3.dmx

rfluxmtx -v -ff  -ab 4 -ad 1000 -lw 0.001 -c 1000 -n 16 varShading/GlazingVmtx4.rad skyDomes/skyglow.rad -i octrees/room3ph.oct > matrices/dmtx/daylight4.dmx

#Create sky-vector
gendaylit 3 20 10:30EDT -m 75 -o 73.96 -a 40.78 -W 706 162 | genskyvec -m 1 > skyVectors/NYC_Per.vec


#Generating partial results for window groups with a t-matrix with clear glazing.
#Commands for point-in-time calculations are listed below. Commands for annual calculations will be similar to the ones shown in 3Ph.sh

#Results for illuminance.
dctimestep  matrices/vmtx/v1.mtx matrices/tmtx/clear.xml matrices/dmtx/daylight1.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv1C.ill

dctimestep  matrices/vmtx/v2.mtx matrices/tmtx/clear.xml matrices/dmtx/daylight2.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv2C.ill

dctimestep  matrices/vmtx/v3.mtx matrices/tmtx/clear.xml matrices/dmtx/daylight3.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv3C.ill

dctimestep  matrices/vmtx/v4.mtx matrices/tmtx/clear.xml matrices/dmtx/daylight4.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv4C.ill


#Results for imaging.
dctimestep -h matrices/vmtx/hdr/v1%03d.hdr matrices/tmtx/clear.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv1C.hdr

dctimestep -h matrices/vmtx/hdr/v2%03d.hdr matrices/tmtx/clear.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv2C.hdr

dctimestep -h matrices/vmtx/hdr/v3%03d.hdr matrices/tmtx/clear.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv3C.hdr

dctimestep -h matrices/vmtx/hdr/v4%03d.hdr matrices/tmtx/clear.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv4C.hdr


#Generating partial results for window groups with a t-matrix with venetian blinds at 45 degrees.

##Results for illuminance.
dctimestep  matrices/vmtx/v1.mtx matrices/tmtx/ven45.xml matrices/dmtx/daylight1.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv1V.ill

dctimestep  matrices/vmtx/v2.mtx matrices/tmtx/ven45.xml matrices/dmtx/daylight2.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv2V.ill

dctimestep  matrices/vmtx/v3.mtx matrices/tmtx/ven45.xml matrices/dmtx/daylight3.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv3V.ill

dctimestep  matrices/vmtx/v4.mtx matrices/tmtx/ven45.xml matrices/dmtx/daylight4.dmx skyVectors/NYC_Per.vec | rmtxop -fa -c 47.4 119.9 11.6 - > results/3ph/varShad/3phv4V.ill


##Results for imaging.
dctimestep -h matrices/vmtx/hdr/v1%03d.hdr matrices/tmtx/ven45.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv1V.hdr

dctimestep -h matrices/vmtx/hdr/v2%03d.hdr matrices/tmtx/ven45.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv2V.hdr

dctimestep -h matrices/vmtx/hdr/v3%03d.hdr matrices/tmtx/ven45.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv3V.hdr

dctimestep -h matrices/vmtx/hdr/v4%03d.hdr matrices/tmtx/ven45.xml matrices/dmtx/daylight.dmx skyVectors/NYC_Per.vec > results/3ph/varShad/3phv4V.hdr


#FINAL RESULTS

#1. Blinds pulled up.
##Illuminance
rmtxop results/3ph/varShad/3phv1C.ill + results/3ph/varShad/3phv2C.ill + results/3ph/varShad/3phv3C.ill + results/3ph/varShad/3phv4C.ill > results/3ph/varShad/3phV00.ill

##Image
pcomb results/3ph/varShad/3phv1C.hdr results/3ph/varShad/3phv2C.hdr results/3ph/varShad/3phv3C.hdr results/3ph/varShad/3phv4C.hdr > results/3ph/varShad/3phV00.hdr

#2. Blinds at 25%
##Illuminance
rmtxop results/3ph/varShad/3phv1V.ill + results/3ph/varShad/3phv2C.ill + results/3ph/varShad/3phv3C.ill + results/3ph/varShad/3phv4C.ill > results/3ph/varShad/3phV25.ill

##Image
pcomb results/3ph/varShad/3phv1V.hdr results/3ph/varShad/3phv2C.hdr results/3ph/varShad/3phv3C.hdr results/3ph/varShad/3phv4C.hdr > results/3ph/varShad/3phV25.hdr


#3. Blinds at 100%
##Illuminance
rmtxop results/3ph/varShad/3phv1V.ill + results/3ph/varShad/3phv2V.ill + results/3ph/varShad/3phv3V.ill + results/3ph/varShad/3phv4V.ill > results/3ph/varShad/3phV100.ill

##Image
pcomb results/3ph/varShad/3phv1V.hdr results/3ph/varShad/3phv2V.hdr results/3ph/varShad/3phv3V.hdr results/3ph/varShad/3phv4V.hdr > results/3ph/varShad/3phV100.hdr


#Done! (The results can be found in the results/3ph/varShad folder).
